Agora-Fountain
==============

The Agora core service for ontology paths discovery and seed management.

Agora-Fountain is distributed under the Apache License, version 2.0.

## Build Status

[![Build Status](https://travis-ci.org/SmartDeveloperHub/agora-fountain.svg?branch=master)](https://travis-ci.org/SmartDeveloperHub/agora-fountain)
[![Coverage Status](https://coveralls.io/repos/SmartDeveloperHub/agora-fountain/badge.svg?branch=master&service=github)](https://coveralls.io/github/SmartDeveloperHub/agora-fountain?branch=master)